==> zio-aws-docdb_2.13-5.17.188.1-sources.jar: zio/aws/docdb/model/DescribeEngineDefaultClusterParametersRequest.scala <==
package zio.aws.docdb.model
import zio.aws.docdb.model.primitives.IntegerOptional
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeEngineDefaultClusterParametersRequest(
    dbParameterGroupFamily: String,
    filters: Optional[Iterable[zio.aws.docdb.model.Filter]] = Optional.Absent,
    maxRecords: Optional[IntegerOptional] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest = {
    import DescribeEngineDefaultClusterParametersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
      .builder()
      .dbParameterGroupFamily(dbParameterGroupFamily: java.lang.String)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest.ReadOnly =
    zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest
      .wrap(buildAwsValue())
}
object DescribeEngineDefaultClusterParametersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest =
      zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest(
        dbParameterGroupFamily,
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def dbParameterGroupFamily: String
    def filters: Optional[List[zio.aws.docdb.model.Filter.ReadOnly]]
    def maxRecords: Optional[IntegerOptional]
    def marker: Optional[String]
    def getDbParameterGroupFamily: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbParameterGroupFamily)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
  ) extends zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest.ReadOnly {
    override val dbParameterGroupFamily: String =
      impl.dbParameterGroupFamily(): String
    override val filters: Optional[List[zio.aws.docdb.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.Filter.wrap(item)
          }.toList
        )
    override val maxRecords: Optional[IntegerOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRecords())
      .map(value => value: IntegerOptional)
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
  ): zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-docdb_3-5.17.224.3-sources.jar: zio/aws/docdb/model/DescribeEngineDefaultClusterParametersRequest.scala <==
package zio.aws.docdb.model
import zio.aws.docdb.model.primitives.IntegerOptional
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class DescribeEngineDefaultClusterParametersRequest(
    dbParameterGroupFamily: String,
    filters: Optional[Iterable[zio.aws.docdb.model.Filter]] = Optional.Absent,
    maxRecords: Optional[IntegerOptional] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest = {
    import DescribeEngineDefaultClusterParametersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
      .builder()
      .dbParameterGroupFamily(dbParameterGroupFamily: java.lang.String)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest.ReadOnly =
    zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest
      .wrap(buildAwsValue())
}
object DescribeEngineDefaultClusterParametersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest =
      zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest(
        dbParameterGroupFamily,
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def dbParameterGroupFamily: String
    def filters: Optional[List[zio.aws.docdb.model.Filter.ReadOnly]]
    def maxRecords: Optional[IntegerOptional]
    def marker: Optional[String]
    def getDbParameterGroupFamily: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbParameterGroupFamily)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
  ) extends zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest.ReadOnly {
    override val dbParameterGroupFamily: String =
      impl.dbParameterGroupFamily(): String
    override val filters: Optional[List[zio.aws.docdb.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.Filter.wrap(item)
          }.toList
        )
    override val maxRecords: Optional[IntegerOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRecords())
      .map(value => value: IntegerOptional)
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeEngineDefaultClusterParametersRequest
  ): zio.aws.docdb.model.DescribeEngineDefaultClusterParametersRequest.ReadOnly =
    new Wrapper(impl)
}
